/*!
  @header BDBDatabaseEntry
  @abstract BDB 
 
  @availability OS X, GNUstep
  @copyright (C) 2004, 2005, 2006 Oliver Langer
 
  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  03.01.2005 ola     initial version
  22.08.2006 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/

#if !defined(__BDBDATABASE_ENTRY_H)
#define __BDBDATABASE_ENTRY_H

#include <Foundation/Foundation.h>
#include <BDB/BDBObject.h>
#include <BDB/BDBDatabaseEntryData.h>


/*!
 * @class BDBDatabaseEntry
 * @abstract data class mainly used for data store/retrieval
 * @discussion This class supportes serialization of {@link NSCoding} based
 *   instances.
 */
@interface BDBDatabaseEntry : BDBDatabaseEntryData

/*!
 * @method initWithObject
 * @abstract Initializes this instance with the given object
 * @param object to use
 */
- initWithObject: (id <NSCoding>) object;


/*!
 * @method dataWithDeserializationMethodInfo
 * @abstract Internal method with returns the data to be decoded and gives
 * the hint about the underlying decoding method to be used
 * @param deserializationInfo If not NULL then it will be set giving a hint 
 *   about the deserialization method to be used.
 * @result data to be decoded or nil if not existent
 */
- (NSData *) dataWithDeserializationMethodInfo: (int *) deserializationInfo;


/*!
 * @method object
 * @result return the encoded object. Caller is responsible for releasing the
 * returned object.
 */
- object;


/*!
 * @method BDBDatabaseEntry
 * @abstract Internal method to specify information about encoding/decoding
 * @param dataToSet encoded data to set
 * @param serializationMethod hint about the method
 * @result self
 */
- setData: (NSData *) dataToSet 
  usedSerializationMethod: (int) serializationMethod;
  
@end
#endif
