/*!  
  @header BDBOperationStatus
  @abstract BDB module
 
  @availability OS X, GNUstep
  @copyright (C) 2004, 2005, 2006 Oliver Langer
 
  Author: Oliver Langer

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA

  <pre>
  -------------------------------------------------------------------------
  Modification history

  04.12.2005 ola     initial version
  22.08.2006 ola     license changed
  -------------------------------------------------------------------------
  </pre>
*/


#if !defined(__BDBOPERATION_STATUS_H)
#define __BDBOPERATION_STATUS_H

#include <db.h>
#include <limits.h>


/*!
 * @enum BDBOperationStatus
 * Result code of diverse operations
 */
typedef enum {
  BDB_STATUS_SUCCESS = 0,
  
  /**
   * data is missing or has never been given for specified key
   */
  BDB_STATUS_KEYEMPTY = DB_KEYEMPTY,
  
  /**
   * key/data pair does not exists
   */
  BDB_STATUS_NOTFOUND = DB_NOTFOUND,
  
  /**
   * Using either mode DB_NOOVERWRITE, DB_NODUPDATA, the specified key already
   * exists.
   */
  BDB_STATUS_KEYEXIST = DB_KEYEXIST,
  
  /**
   * Should never be returned
   */
  BDB_STATUS_UNKNOWN = INT_MAX
} BDBOperationStatus;

#endif
